web3_universal_ledger library

Ledger hardware wallet integration for Dart Web3 SDK

This library provides integration with Ledger hardware wallets using USB and Bluetooth Low Energy (BLE) communication.

Classes

APDUCommand
APDU command structure
APDUResponse
APDU response structure
EthereumAPDU
APDU commands for Ledger Ethereum app
EthereumAppConfig
Ethereum app configuration
EthereumResponseParser
Response parsers for Ethereum app
LedgerAccount
Ledger account information
LedgerApp
Ledger application information
LedgerBLETransport
Bluetooth Low Energy transport implementation (mock for pure Dart)
LedgerClient
Ledger hardware wallet client
LedgerDevice
Ledger device information
LedgerMultiChainSigner
Multi-chain signing support for Ledger
LedgerSigner
Ledger hardware wallet signer implementation
LedgerSignRequest
Signing request for Ledger
LedgerSignResponse
Ledger signing response
LedgerTransport
Abstract transport interface for Ledger communication
LedgerTransportFactory
Transport factory for creating appropriate transport
LedgerUSBTransport
USB transport implementation (mock for pure Dart)
MockLedgerTransport
Mock transport for testing
MultiChainDerivationPaths
Multi-chain derivation path utilities
TestLedgerTransport
Advanced test transport that simulates Ledger device responses with APDU commands.

Enums

ChainType
Supported blockchain types
LedgerConnectionState
Ledger connection state
LedgerErrorType
Ledger error types
LedgerSignType
Types of signing operations
LedgerTransportType
Ledger transport types

Exceptions / Errors

LedgerException
Ledger exception