LedgerMultiChainSigner class
Multi-chain signing support for Ledger
Constructors
- LedgerMultiChainSigner(LedgerClient _client)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAddress(
String derivationPath, ChainType chainType) → Future< String> - Get address for different chains
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
signBitcoinTransaction(
Uint8List transactionData, String derivationPath) → Future< String> - Sign Bitcoin transaction using Bitcoin app
-
signPolkadotTransaction(
Uint8List transactionData, String derivationPath) → Future< String> - Sign Polkadot transaction using Polkadot app
-
signSolanaTransaction(
Uint8List transactionData, String derivationPath) → Future< String> - Sign Solana transaction using Solana app
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited