LedgerSigner class
Ledger hardware wallet signer implementation
Constructors
- LedgerSigner(LedgerClient _client, String _derivationPath)
Properties
- account → LedgerAccount?
-
Get the current account information
no setter
- address → EthereumAddress
-
The signer's Ethereum address.
no setter
- client → LedgerClient
-
Get the Ledger client
no setter
- derivationPath → String
-
Get the derivation path
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
connect(
) → Future< void> - Connects to the hardware wallet.
-
disconnect(
) → Future< void> - Disconnects from the hardware wallet.
-
getAddresses(
{int count = 5, int offset = 0}) → Future< List< EthereumAddress> > - Gets available addresses from the hardware wallet.
-
isConnected(
) → Future< bool> - Checks if the hardware wallet is connected.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
signAuthorization(
Authorization authorization) → Future< Uint8List> - Signs an EIP-7702 authorization.
-
signHash(
Uint8List hash) → Future< Uint8List> - Signs a raw hash directly without any prefix.
-
signMessage(
String message) → Future< Uint8List> - Signs a personal message (EIP-191).
-
signTransaction(
TransactionRequest transaction) → Future< Uint8List> - Signs a transaction and returns the signed transaction bytes.
-
signTypedData(
EIP712TypedData typedData) → Future< Uint8List> - Signs typed data (EIP-712).
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
{required LedgerClient client, String derivationPath = "m/44'/60'/0'/0/0"}) → Future< LedgerSigner> - Create a Ledger signer for a specific account